function V=surv_cond(t,x,Y,X,d,h,kernel,typew)
% KERNEL ESTIMATION OF SURVIVAL FUNCTION
% inputs: t     ...time points in which we want calculate hazard, vector
%         x     ...vector of covariates we want to calculate hazard
%         Y     ...observed times, vector
%         X     ...vector of observed covariates
%         d     ...censoring indicator, vector, 0..censor, 1..event
%         h     ...vector of smoothing parameter h=c(ht,hx)
%           ht    ...smoothing parameter, number
%           hx    ...smoothing parameter for weights
%         typew   ... type of weights
%         kernel...one of: 'epan','gauss','quart','rect'
% output: matrix of hazard values in times t and covariates x
%         j-th row of matrix is vector of hazard values in times t for j-th covariate in x
%         i-th column of matrix is vector of hazard values in i-th time in t for vector of covariate x
%         j-th row and i-th column .. i-th time, j-th covariate
%



hx=h(2);
ht=h(1);


tt=row(t);
xx=row(x);
Y=row(Y);
X=row(X);
d=row(d);
n=length(Y);
m=length(tt);


K=K_def(kernel);
W=W_def(K);

switch typew
    case 'nw'
        M=nwmatrix(X,hx,xx,K);
    case 'll'
        M=llmatrix(X,hx,xx,K);
        
end
%matice Y-tt
Ymat=Y'*ones(1,m)-ones(n,1)*tt;

t=(W_val(W,Ymat/ht));

V=M*t;
V(V<=0.005)=0.005;

if strcmp(typew, 'll')
    V(V<0)=0;
end

end

